==> qtcreator_4.5.2.orig.tar.xz: qt-creator-opensource-src-4.5.2/src/plugins/clangpchmanager/pchmanagernotifierinterface.h <==
/****************************************************************************
**
** Copyright (C) 2016 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3 as published by the Free Software
** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-3.0.html.
**
****************************************************************************/

#pragma once

#include <QtGlobal>

QT_FORWARD_DECLARE_CLASS(QString)

namespace ClangPchManager {

class PchManagerClient;

class PchManagerNotifierInterface
{
public:
    PchManagerNotifierInterface(PchManagerClient &pchManagerClient);

    virtual ~PchManagerNotifierInterface();
    virtual void precompiledHeaderUpdated(const QString &projectPartId,
                                          const QString &pchFilePath) = 0;
    virtual void precompiledHeaderRemoved(const QString &projectPartId) = 0;

    PchManagerClient &m_pchManagerClient;
};

} // namespace ClangPchManager

==> qtcreator_4.11.0.orig.tar.xz: qt-creator-opensource-src-4.11.0/src/plugins/clangpchmanager/pchmanagernotifierinterface.h <==
/****************************************************************************
**
** Copyright (C) 2016 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3 as published by the Free Software
** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-3.0.html.
**
****************************************************************************/

#pragma once

#include "clangpchmanager_global.h"

#include <projectpartid.h>

QT_FORWARD_DECLARE_CLASS(QString)

namespace ClangPchManager {

class PchManagerClient;

class CLANGPCHMANAGER_EXPORT PchManagerNotifierInterface
{
public:
    PchManagerNotifierInterface(PchManagerClient &pchManagerClient);
    PchManagerNotifierInterface(const PchManagerNotifierInterface &) = delete;
    PchManagerNotifierInterface &operator=(const PchManagerNotifierInterface &) = delete;

    virtual void precompiledHeaderUpdated(ClangBackEnd::ProjectPartId projectPartId) = 0;
    virtual void precompiledHeaderRemoved(ClangBackEnd::ProjectPartId projectPartId) = 0;

    PchManagerClient &m_pchManagerClient;

protected:
    ~PchManagerNotifierInterface();
};

} // namespace ClangPchManager
